@@ -55,7 +55,9 @@ giftRegions <- function(species,min_size=1000,max_size=100000000000){
           if(i == 1){
             regs <- b
           }else{
-            regs <- spRbind(regs,b)
+            if(ncol(regs) == ncol(b)){
+              regs <- spRbind(regs,b)
+            }
           }
         }
       }
